==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/IoTAnalytics/CreateDatasetContent.pm <==

package Paws::IoTAnalytics::CreateDatasetContent;
  use Moose;
  has DatasetName => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'datasetName', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateDatasetContent');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/datasets/{datasetName}/content');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoTAnalytics::CreateDatasetContent - Arguments for method CreateDatasetContent on L<Paws::IoTAnalytics>

=head1 DESCRIPTION

This class represents the parameters used for calling the method CreateDatasetContent on the
L<AWS IoT Analytics|Paws::IoTAnalytics> service. Use the attributes of this class
as arguments to method CreateDatasetContent.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CreateDatasetContent.

=head1 SYNOPSIS

    my $iotanalytics = Paws->service('IoTAnalytics');
    $iotanalytics->CreateDatasetContent(
      DatasetName => 'MyDatasetName',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/iotanalytics/CreateDatasetContent>

=head1 ATTRIBUTES


=head2 B<REQUIRED> DatasetName => Str

The name of the data set.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CreateDatasetContent in L<Paws::IoTAnalytics>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/IoTAnalytics/CreateDatasetContent.pm <==

package Paws::IoTAnalytics::CreateDatasetContent;
  use Moose;
  has DatasetName => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'datasetName', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateDatasetContent');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/datasets/{datasetName}/content');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IoTAnalytics::CreateDatasetContentResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoTAnalytics::CreateDatasetContent - Arguments for method CreateDatasetContent on L<Paws::IoTAnalytics>

=head1 DESCRIPTION

This class represents the parameters used for calling the method CreateDatasetContent on the
L<AWS IoT Analytics|Paws::IoTAnalytics> service. Use the attributes of this class
as arguments to method CreateDatasetContent.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CreateDatasetContent.

=head1 SYNOPSIS

    my $iotanalytics = Paws->service('IoTAnalytics');
    my $CreateDatasetContentResponse = $iotanalytics->CreateDatasetContent(
      DatasetName => 'MyDatasetName',

    );

    # Results:
    my $VersionId = $CreateDatasetContentResponse->VersionId;

    # Returns a L<Paws::IoTAnalytics::CreateDatasetContentResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/iotanalytics/CreateDatasetContent>

=head1 ATTRIBUTES


=head2 B<REQUIRED> DatasetName => Str

The name of the data set.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CreateDatasetContent in L<Paws::IoTAnalytics>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
